==> HostCMS.Free_6.7.tar.gz: modules/shop/delivery/condition/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Delivery conditions',
	'show_cond_of_delivery_title' => "Conditions for delivery \"%s\"",
	'show_cond_of_delivery' => "Delivery conditions",
	'show_cond_of_delivery_add' => "Add",
	'show_cond_of_delivery_import' => "Import",
	'cond_of_delivery_edit_form_title' => "Edit delivery conditions",
	'cond_of_delivery_add_form_title' => "Add delivery conditions",
	'name' => "<acronym title=\"Name of delivery condition\">Name</acronym>",
	'active' => "<acronym title=\"Activity of delivery condition\">Active</acronym>",
	'delivery_time' => "<acronym title=\"Delivery time\">Delivery time</acronym>",
	'shop_country_id' => "<acronym title=\"Country of delivery\">Country</acronym>",
	'shop_country_location_id' => "<acronym title=\"Location of delivery\">Location</acronym>",
	'shop_country_location_city_id' => "<acronym title=\"Delivery city/town\">City/town</acronym>",
	'shop_country_location_city_area_id' => "<acronym title=\"Region of delivery\">Region</acronym>",
	'min_weight' => "Order weight from (%s); if 0 &mdash; minimum order weight is unlimited",
	'max_weight' => "Order weight to (%s); if 0 &mdash; maximum order weight is unlimited",
	'min_price' => "Order price from; if 0 &mdash; minimum order price is unlimited",
	'max_price' => "Order price to; if 0 &mdash; maximum order price is unlimited",
	'description' => "<acronym title=\"Description of delivery condition\">Description</acronym>",
	'price' => "<acronym title=\"Amount of ordered products\">Order amount</acronym>",
	'shop_tax_id' => "Tax value",
	'cond_of_delivery_tab' => "Delivery conditions",
	'shop_delivery_id' => "<acronym title=\"Delivery condition belongs to\">Delivery condition belongs to</acronym>",
	'id' => 'Id',
	'edit_success' => "Delivery condition information added successfully!",
	'shop_measure_not_checked' => "The measure is not selected for shop",
	'markDeleted_success' => "Delivery conditions deleted successfully!",
	'import_button' => "Import",
	'import_price_list_file_type' => "Select file",
	'msg_import_file' => 'Import file not specified!',
	'import_delivery_result' => "There were %s elements imported",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeStatus_success' => "Information has been successfully changed",	
	'marking' => "Delivery Marking",
	'sorting' => "<acronym title=\"Sorting order\">Sorting order</acronym>",
	'apply_success' => "Information has been successfully changed",
	'inverted' => "Not",
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/delivery/condition/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Delivery conditions',
	'show_cond_of_delivery_title' => "Conditions for delivery \"%s\"",
	'show_cond_of_delivery' => "Delivery conditions",
	'show_cond_of_delivery_add' => "Add",
	'show_cond_of_delivery_import' => "Import",
	'cond_of_delivery_edit_form_title' => "Edit delivery conditions",
	'cond_of_delivery_add_form_title' => "Add delivery conditions",
	'name' => "Name",
	'active' => "Active",
	'delivery_time' => "Delivery time",
	'shop_country_id' => "Country",
	'shop_country_location_id' => "Location",
	'shop_country_location_city_id' => "City/town",
	'shop_country_location_city_area_id' => "Region",
	'min_weight' => "Order weight from (%s); if 0 &mdash; minimum order weight is unlimited",
	'max_weight' => "Order weight to (%s); if 0 &mdash; maximum order weight is unlimited",
	'min_price' => "Order price from; if 0 &mdash; minimum order price is unlimited",
	'max_price' => "Order price to; if 0 &mdash; maximum order price is unlimited",
	'description' => "Description",
	'price' => "Order amount",
	'shop_tax_id' => "Tax value",
	'cond_of_delivery_tab' => "Delivery conditions",
	'shop_delivery_id' => "Delivery condition belongs to",
	'id' => 'ID',
	'edit_success' => "Delivery condition information added successfully!",
	'copy_success' => 'Information has been copied successfully!',
	'shop_measure_not_checked' => "The measure is not selected for shop",
	'markDeleted_success' => "Delivery conditions deleted successfully!",
	'import_button' => "Import",
	'import_price_list_file_type' => "Select file",
	'msg_import_file' => 'Import file not specified!',
	'import_delivery_result' => "There were %s elements imported",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeStatus_success' => "Information has been successfully changed",
	'marking' => "Delivery Marking",
	'sorting' => 'Sort',
	'apply_success' => "Information has been successfully changed",
	'inverted' => "Not",
	'time_from' => "Order time from, if you specify 00:00:00 &mdash; time is unlimited",
	'time_to' => "Order time is until, when 00:00:00 &mdash; is specified, time is unlimited",
);
